cocos.scenes.pause module — cocos v0.6.5 documentation

# cocos.scenes.pause module

Pause scene

class `PauseLayer`

  Bases: `cocos.layer.base_layers.Layer`

  Layer that shows the text ‘PAUSED’

  `draw`()
  `on_key_press`(k, m)
  `is_event_handler` = True

    enable pyglet’s events

class `PauseScene`(background, *layers)

  Bases: `cocos.scene.Scene`

  Pause Scene

  `draw`()

`default_pause_scene`()

`get_pause_scene`()

`set_pause_scene_generator`(generator)